@@ -111,6 +111,14 @@ SQLCancel(HSTMT StatementHandle)
 	return DiscardStatementSvp(stmt, ret, FALSE);
 }
 
+static BOOL theResultIsEmpty(const StatementClass *stmt)
+{
+	QResultClass	*res = SC_get_Result(stmt);
+	if (NULL == res)
+		return FALSE;
+	return (0 == QR_get_num_total_tuples(res));
+}
+
 RETCODE		SQL_API
 SQLColumns(HSTMT StatementHandle,
 		   SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
@@ -139,7 +147,7 @@ SQLColumns(HSTMT StatementHandle,
 		ret = PGAPI_Columns(StatementHandle, ctName, NameLength1,
 				scName, NameLength2, tbName, NameLength3,
 				clName, NameLength4, flag, 0, 0);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newTb = NULL, *newCl = NULL;
@@ -787,7 +795,7 @@ SQLSpecialColumns(HSTMT StatementHandle,
 		ret = PGAPI_SpecialColumns(StatementHandle, IdentifierType, ctName,
 			NameLength1, scName, NameLength2, tbName, NameLength3,
 							Scope, Nullable);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt =NULL, *newSc = NULL, *newTb = NULL;
@@ -850,7 +858,7 @@ SQLStatistics(HSTMT StatementHandle,
 		ret = PGAPI_Statistics(StatementHandle, ctName, NameLength1,
 				 scName, NameLength2, tbName, NameLength3,
 				 Unique, Reserved);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt =NULL, *newSc = NULL, *newTb = NULL;
@@ -918,7 +926,7 @@ SQLTables(HSTMT StatementHandle,
 		ret = PGAPI_Tables(StatementHandle, ctName, NameLength1,
 				scName, NameLength2, tbName, NameLength3,
 					TableType, NameLength4, flag);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt =NULL, *newSc = NULL, *newTb = NULL;
@@ -1037,7 +1045,7 @@ SQLColumnPrivileges(
 		ret = PGAPI_ColumnPrivileges(hstmt, ctName, cbCatalogName,
 				scName, cbSchemaName, tbName, cbTableName,
 						clName, cbColumnName, flag);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newTb = NULL, *newCl = NULL;
@@ -1178,7 +1186,7 @@ SQLForeignKeys(
 			pkscName, cbPkSchemaName, pktbName, cbPkTableName,
 			fkctName, cbFkCatalogName, fkscName, cbFkSchemaName,
 			fktbName, cbFkTableName);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newPkct = NULL, *newPksc = NULL, *newPktb = NULL,
@@ -1343,7 +1351,7 @@ SQLPrimaryKeys(
 	else
 		ret = PGAPI_PrimaryKeys(hstmt, ctName, cbCatalogName,
 			scName, cbSchemaName, tbName, cbTableName, 0);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newTb = NULL;
@@ -1416,7 +1424,7 @@ SQLProcedureColumns(
 		ret = PGAPI_ProcedureColumns(hstmt, ctName, cbCatalogName,
 				scName, cbSchemaName, prName, cbProcName,
 					clName, cbColumnName, flag);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newPr = NULL, *newCl = NULL;
@@ -1495,7 +1503,7 @@ SQLProcedures(
 		ret = PGAPI_Procedures(hstmt, ctName, cbCatalogName,
 					 scName, cbSchemaName, prName,
 					 cbProcName, flag);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newPr = NULL;
@@ -1585,7 +1593,7 @@ SQLTablePrivileges(
 	else
 		ret = PGAPI_TablePrivileges(hstmt, ctName, cbCatalogName,
 			scName, cbSchemaName, tbName, cbTableName, flag);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newTb = NULL;
